@@ -1,6 +1,4 @@
 
-import PyQt5.QtWidgets as QtWidgets
-import PyQt5.QtCore as QtCore
 import PyQt5.QtGui as QtGui
 
 # needed right after QT imports for high-DPI screens
